@@ -7,15 +7,12 @@ from typing import (TYPE_CHECKING, Any, Callable, Generic, Optional, Sequence,
                     Type, TypeVar, cast)
 
 from . import fields, file, fstree, site, toposort
-from .asset import Asset
 from .node import Node
 from .page import Page
 
 if TYPE_CHECKING:
     import argparse
 
-    import jinja2
-
     from .archetypes import Archetype, Archetypes
     from .source_node import SourcePageNode
 
@@ -216,11 +213,7 @@ class Features:
         self.node_classes: dict[Type[Node], Type[Node]] = {}
 
         # Cached final page classes indexed by original page class
-        self.page_classes: dict[Type[Page], Type[Page]] = {
-            # Preinit with Asset being a final page, without any mixin added
-            # from features
-            Asset: Asset,
-        }
+        self.page_classes: dict[Type[Page], Type[Page]] = {}
 
         # Features sorted by topological order
         self.sorted: Optional[list[Feature]] = None
@@ -276,15 +269,15 @@ class Features:
 
             for name in feature.RUN_AFTER:
                 if name not in features and name not in graph:
-                    log.warn("feature %s: ignoring RUN_AFTER relation on %s which is not available",
-                             feature, name)
+                    log.warning("feature %s: ignoring RUN_AFTER relation on %s which is not available",
+                                feature, name)
                     continue
                 graph[feature.NAME].add(name)
 
             for name in feature.RUN_BEFORE:
                 if name not in features and name not in graph:
-                    log.warn("feature %s: ignoring RUN_BEFORE relation on %s which is not available",
-                             feature, name)
+                    log.warning("feature %s: ignoring RUN_BEFORE relation on %s which is not available",
+                                feature, name)
                     continue
                 graph[name].add(feature.NAME)
 
@@ -352,7 +345,7 @@ class Features:
 
             features = getattr(mod, "FEATURES", None)
             if features is None:
-                log.warn("%r: feature module did not define a FEATURES dict", name)
+                log.warning("%r: feature module did not define a FEATURES dict", name)
                 continue
 
             # Register features with site
