@@ -1,7 +1,8 @@
 from __future__ import annotations
-from typing import NamedTuple, Optional
-import os
+
 import logging
+import os
+from typing import Generator, NamedTuple
 
 log = logging.getLogger("contents")
 
@@ -15,42 +16,33 @@ class File(NamedTuple):
     # Relative path to root
     relpath: str
     # Absolute path to the file
-    abspath: Optional[str] = None
+    abspath: str
     # File stats if the file exists, else None
-    stat: Optional[os.stat_result] = None
+    stat: os.stat_result
 
-    def __str__(self):
+    def __str__(self) -> str:
         if self.abspath:
             return self.abspath
         else:
             return self.relpath
 
     @classmethod
-    def from_abspath(cls, tree_root: str, abspath: str) -> "File":
-        return cls(
-                relpath=os.path.relpath(abspath, tree_root),
-                abspath=abspath)
-
-    @classmethod
-    def from_dir_entry(cls, dir: "File", entry: os.DirEntry) -> "File":
-        try:
-            st = entry.stat()
-        except FileNotFoundError:
-            log.warning("%s: cannot stat() file: broken symlink?",
-                      os.path.join(dir.abspath, entry.name))
-            st = None
-
+    def from_dir_entry(cls, dir: "File", entry: os.DirEntry[str]) -> "File":
         return cls(
                 relpath=os.path.join(dir.relpath, entry.name),
                 abspath=os.path.join(dir.abspath, entry.name),
-                stat=st)
+                stat=entry.stat())
 
     @classmethod
-    def with_stat(cls, relpath: str, abspath: str):
+    def with_stat(cls, relpath: str, abspath: str) -> File:
         return cls(relpath, abspath, os.stat(abspath))
 
     @classmethod
-    def scan(cls, abspath, follow_symlinks=False, ignore_hidden=False):
+    def scan(
+            cls,
+            abspath: str,
+            follow_symlinks: bool = False,
+            ignore_hidden: bool = False) -> Generator[File, None, None]:
         """
         Scan tree_root, generating relative paths based on it
         """
