@@ -362,8 +362,8 @@ class Related(collections.abc.MutableMapping[str, "Page"]):
 
     def __setitem__(self, name: str, page: Union[str, Page]) -> None:
         if (old := self.pages.get(name)) is not None and old != self.page:
-            log.warn("%s: attempt to set related.%s to %r but it was already %r",
-                     self, name, page, old)
+            log.warning("%s: attempt to set related.%s to %r but it was already %r",
+                        self, name, page, old)
             return
         self.pages[name] = page
 
@@ -786,6 +786,17 @@ It defaults to false, or true if `meta.date` is in the future.
         return res
 
 
+class StandaloneAutoPage(Page):
+    """
+    Page that has been autogenerated, but not from another page
+    """
+    def __init__(
+            self, site: Site, *,
+            node: Node,
+            **kw: Any) -> None:
+        super().__init__(site, parent=node, node=node, **kw)
+
+
 class AutoPage(Page):
     """
     Autogenerated page
@@ -798,7 +809,7 @@ class AutoPage(Page):
 
     def __init__(
             self, site: Site, *,
-            created_from: Optional[Page] = None,
+            created_from: Page,
             **kw: Any) -> None:
         if created_from is None:
             raise RuntimeError("created_from is None in AutoPage")
