@@ -1,15 +1,16 @@
 from __future__ import annotations
-from typing import Dict, Any, Tuple, BinaryIO, TextIO, Iterable
-from .typing import Meta
-import logging
+
 import json
+import logging
 import re
+from typing import IO, Any, Generator, Iterable, Optional
+
 from . import yaml_codec
 
 log = logging.getLogger("utils")
 
 
-def write(meta: Dict[str, Any], style: str = "toml") -> str:
+def write(meta: dict[str, Any], style: str = "toml") -> str:
     if style == "json":
         return json.dumps(meta, indent=4, sort_keys=True)
     elif style == "toml":
@@ -20,7 +21,7 @@ def write(meta: Dict[str, Any], style: str = "toml") -> str:
     return ""
 
 
-def read_markdown_partial(fd: BinaryIO) -> Tuple[str, Meta, Iterable[str]]:
+def read_markdown_partial(fd: IO[bytes]) -> tuple[Optional[str], dict[str, Any], Iterable[str]]:
     """
     Parse lines front matter from a markdown file header.
 
@@ -64,18 +65,18 @@ def read_markdown_partial(fd: BinaryIO) -> Tuple[str, Meta, Iterable[str]]:
             if not line or line.rstrip() == b"```":
                 break
             buf += line
-        if head[3:] == "yaml":
+        if head[3:] == b"yaml":
             return "yaml", yaml_codec.loads(buf.decode()), (x.rstrip().decode() for x in fd)
-        elif head[3:] == "toml":
+        elif head[3:] == b"toml":
             import toml
             return "toml", toml.loads(buf.decode()), (x.rstrip().decode() for x in fd)
-        elif head[3:] == "json":
+        elif head[3:] == b"json":
             return "json", json.loads(buf.decode()), (x.rstrip().decode() for x in fd)
         else:
             return "yaml", yaml_codec.loads(buf.decode()), (x.rstrip().decode() for x in fd)
     else:
         # No front matter found
-        def iter_body():
+        def iter_body() -> Generator[str, None, None]:
             yield line.rstrip().decode()
             for x in fd:
                 yield x.rstrip().decode()
@@ -85,7 +86,7 @@ def read_markdown_partial(fd: BinaryIO) -> Tuple[str, Meta, Iterable[str]]:
 re_toml = re.compile(r"^\+\+\+[ \t]*\n(.+?)\n\+\+\+[ \t]*\n$", re.DOTALL)
 
 
-def read_whole(fd: TextIO) -> Tuple[str, Meta]:
+def read_whole(fd: IO[str]) -> tuple[str, dict[str, Any]]:
     """
     Parse lines front matter from a file header.
 
@@ -95,17 +96,17 @@ def read_whole(fd: TextIO) -> Tuple[str, Meta]:
     """
     content = fd.read()
     if content.startswith("{"):
-        return "json", json.loads(content)
+        return "json", (val if (val := json.loads(content)) is not None else {})
 
     mo = re_toml.match(content)
     if mo:
         import toml
-        return "toml", toml.loads(mo.group(1))
+        return "toml", (val if (val := toml.loads(mo.group(1))) is not None else {})
 
-    return "yaml", yaml_codec.loads(content)
+    return "yaml", (val if (val := yaml_codec.loads(content)) is not None else {})
 
 
-def read_string(content: str) -> Tuple[str, Meta]:
+def read_string(content: str) -> tuple[str, dict[str, Any]]:
     """
     Parse lines front matter from a file header.
 
