@@ -3,7 +3,7 @@ import os
 from . import utils as test_utils
 
 
-class TestMetadata(TestCase):
+class TestMetadata(test_utils.MockSiteTestMixin, TestCase):
     """
     Test metadata collected on site load
     """
@@ -28,22 +28,17 @@ title: Test1 title
 {% endblock %}""",
         }
 
-        with test_utils.testsite(files) as site:
-            self.assertCountEqual([k for k in site.pages.keys() if not k.startswith("/static/")], [
-                "/", "/test.html", "/test1.html"
-            ])
-
-            index = site.pages["/"]
-            test = site.pages["/test.html"]
-            test1 = site.pages["/test1.html"]
+        with self.site(files) as mocksite:
+            mocksite.assertPagePaths(("", "test.html", "test1.html"))
+            index, test, test1 = mocksite.page("", "test.html", "test1.html")
 
             self.assertEqual(index.TYPE, "jinja2")
             self.assertEqual(test.TYPE, "jinja2")
             self.assertEqual(test1.TYPE, "jinja2")
 
-            self.assertEqual(index.meta["title"], "Default title")
-            self.assertEqual(test.meta["title"], "Test title")
-            self.assertEqual(test1.meta["title"], "Test1 title")
+            self.assertEqual(index.title, "Default title")
+            self.assertEqual(test.title, "Test title")
+            self.assertEqual(test1.title, "Test1 title")
 
     def test_tree_meta(self):
         files = {
@@ -59,18 +54,14 @@ title: Test1 title
             "dir1/dir2/page.md": {},
         }
 
-        with test_utils.workdir(files) as root:
-            site = test_utils.Site(PROJECT_ROOT=root)
-            site.load()
-            site.analyze()
-
-            self.assertEqual(site.pages["/"].meta["site_name"], "Root site")
-            self.assertEqual(site.pages["/page"].meta["site_name"], "Root site")
-            self.assertEqual(site.pages["/page1"].meta["site_name"], "Page 1 site")
-            self.assertEqual(site.pages["/dir1"].meta["site_name"], "Root site")
-            self.assertEqual(site.pages["/dir1/page"].meta["site_name"], "Root site")
-            self.assertEqual(site.pages["/dir1/dir2"].meta["site_name"], "dir2 site")
-            self.assertEqual(site.pages["/dir1/dir2/page"].meta["site_name"], "dir2 site")
+        with self.site(files) as mocksite:
+            self.assertEqual(mocksite.page("").site_name, "Root site")
+            self.assertEqual(mocksite.page("page").site_name, "Root site")
+            self.assertEqual(mocksite.page("page1").site_name, "Page 1 site")
+            self.assertEqual(mocksite.page("dir1").site_name, "Root site")
+            self.assertEqual(mocksite.page("dir1/page").site_name, "Root site")
+            self.assertEqual(mocksite.page("dir1/dir2").site_name, "dir2 site")
+            self.assertEqual(mocksite.page("dir1/dir2/page").site_name, "dir2 site")
 
     def test_asset(self):
         self.maxDiff = None
@@ -87,19 +78,9 @@ title: Test1 title
             "test1.md": {},
         }
 
-        with test_utils.workdir(files) as root:
-            site = test_utils.Site(CONTENT=root)
-            site.load()
-            site.analyze()
-
-            self.assertCountEqual([k for k in site.pages.keys() if not k.startswith("/static/")], [
-                "/", "/test.md", "/test1",
-            ])
-
-            index = site.pages["/"]
-            test = site.pages["/test.md"]
-            test1 = site.pages["/test1"]
-
+        with self.site(files) as mocksite:
+            mocksite.assertPagePaths(("", "test.md", "test1"))
+            index, test, test1 = mocksite.page("", "test.md", "test1")
             self.assertEqual(index.TYPE, "dir")
             self.assertEqual(test.TYPE, "asset")
             self.assertEqual(test1.TYPE, "markdown")
@@ -118,63 +99,42 @@ title: Test1 title
             "examples/subdir/test2.md": {},
         }
 
-        with test_utils.workdir(files) as root:
-            site = test_utils.Site(CONTENT=root)
-            site.load()
-            site.analyze()
-
-            self.assertCountEqual([k for k in site.pages.keys() if not k.startswith("/static/")], [
-                "/", "/test",
-                "/examples/test1.md",
-                "/examples/subdir/test2.md",
-            ])
-
-            index = site.pages["/"]
-            test = site.pages["/test"]
-            test1 = site.pages["/examples/test1.md"]
-            test2 = site.pages["/examples/subdir/test2.md"]
-
+        with self.site(files) as mocksite:
+            mocksite.assertPagePaths(("", "test", "examples/test1.md", "examples/subdir/test2.md"))
+            index, test, test1, test2 = mocksite.page("", "test", "examples/test1.md", "examples/subdir/test2.md")
             self.assertEqual(index.TYPE, "dir")
             self.assertEqual(test.TYPE, "markdown")
             self.assertEqual(test1.TYPE, "asset")
             self.assertEqual(test2.TYPE, "asset")
 
 
-class TestSiteName(TestCase):
+class TestSiteName(test_utils.MockSiteTestMixin, TestCase):
     def test_from_content_dir_name(self):
-        files = {
+        sitedef = test_utils.MockSite({
             "index.md": {},
             "page.md": {},
             "dir/page.md": {},
-        }
+        })
+        sitedef.settings.SITE_NAME = None
 
-        with test_utils.workdir(files) as root:
-            site = test_utils.Site(SITE_NAME=None, CONTENT=root)
-            site.load()
-            site.analyze()
-
-            expected = os.path.basename(root)
-
-            self.assertEqual(site.pages["/"].meta["site_name"], expected)
-            self.assertEqual(site.pages["/page"].meta["site_name"], expected)
-            self.assertEqual(site.pages["/dir/page"].meta["site_name"], expected)
+        with self.site(sitedef) as mocksite:
+            expected = os.path.basename(mocksite.root)
+            self.assertEqual(mocksite.page("").site_name, expected)
+            self.assertEqual(mocksite.page("page").site_name, expected)
+            self.assertEqual(mocksite.page("dir/page").site_name, expected)
 
     def test_from_settings(self):
-        files = {
+        sitedef = test_utils.MockSite({
             "index.md": {},
             "page.md": {},
             "dir/page.md": {},
-        }
+        })
+        sitedef.settings.SITE_NAME = "Site Name"
 
-        with test_utils.workdir(files) as root:
-            # Site name from settings
-            site = test_utils.Site(SITE_NAME="Site Name", CONTENT=root)
-            site.load()
-            site.analyze()
-
-            self.assertEqual(site.pages["/"].meta["site_name"], "Site Name")
-            self.assertEqual(site.pages["/page"].meta["site_name"], "Site Name")
-            self.assertEqual(site.pages["/dir/page"].meta["site_name"], "Site Name")
+        with self.site(sitedef) as mocksite:
+            self.assertEqual(mocksite.page("").site_name, "Site Name")
+            self.assertEqual(mocksite.page("page").site_name, "Site Name")
+            self.assertEqual(mocksite.page("dir/page").site_name, "Site Name")
 
     def test_from_dir_meta(self):
         files = {
@@ -184,37 +144,30 @@ class TestSiteName(TestCase):
             "dir/page.md": {},
         }
 
-        with test_utils.workdir(files) as root:
-            site = test_utils.Site(CONTENT=root)
-            site.load()
-            site.analyze()
-
-            self.assertEqual(site.pages["/"].meta["site_name"], "Site Name dirmeta")
-            self.assertEqual(site.pages["/page"].meta["site_name"], "Site Name dirmeta")
-            self.assertEqual(site.pages["/dir/page"].meta["site_name"], "Site Name dirmeta")
+        with self.site(files) as mocksite:
+            self.assertEqual(mocksite.page("").site_name, "Site Name dirmeta")
+            self.assertEqual(mocksite.page("page").site_name, "Site Name dirmeta")
+            self.assertEqual(mocksite.page("dir/page").site_name, "Site Name dirmeta")
 
     def test_from_root_title(self):
-        files = {
+        sitedef = test_utils.MockSite({
             "index.md": {"title": "Site Name title"},
             "page.md": {},
             "dir/page.md": {},
-        }
+        })
+        sitedef.settings.SITE_NAME = None
 
-        with test_utils.workdir(files) as root:
-            site = test_utils.Site(SITE_NAME=None, CONTENT=root)
-            site.load()
-            site.analyze()
-
-            self.assertEqual(site.pages["/"].meta["site_name"], "Site Name title")
-            self.assertEqual(site.pages["/page"].meta["site_name"], "Site Name title")
-            self.assertEqual(site.pages["/dir/page"].meta["site_name"], "Site Name title")
+        with self.site(sitedef) as mocksite:
+            self.assertEqual(mocksite.page("").site_name, "Site Name title")
+            self.assertEqual(mocksite.page("page").site_name, "Site Name title")
+            self.assertEqual(mocksite.page("dir/page").site_name, "Site Name title")
 
 
-class TestFields(TestCase):
+class TestFields(test_utils.MockSiteTestMixin, TestCase):
     def test_date(self):
         self.maxDiff = None
 
-        files = {
+        sitedef = test_utils.MockSite({
             "index.html": """
 {% block front_matter %}
 ---
@@ -229,22 +182,20 @@ date: 2005-01-01 00:00:00
 data_type: test
 date: 2010-01-01 00:00:00
 """,
-        }
+        })
+        sitedef.settings.SITE_NAME = None
+        sitedef.settings.TIMEZONE = "UTC"
 
-        with test_utils.workdir(files) as root:
-            site = test_utils.Site(SITE_NAME=None, CONTENT=root, TIMEZONE="UTC")
-            site.load()
-            site.analyze()
-
-            j2page = site.pages["/"]
-            mdpage = site.pages["/page"]
-            datapage = site.pages["/page1"]
+        with self.site(sitedef) as mocksite:
+            j2page, mdpage, datapage = mocksite.page("", "page", "page1")
 
             self.assertEqual(j2page.to_dict(), {
                 "src": {
                     "relpath": "index.html",
-                    "abspath": os.path.join(root, "index.html"),
+                    "abspath": os.path.join(mocksite.root, "index.html"),
                 },
+                'site_path': '',
+                "build_path": "index.html",
                 "meta": {
                     "author": "Test User",
                     "copyright": '© 2000 Test User',
@@ -253,11 +204,11 @@ date: 2010-01-01 00:00:00
                     'indexed': True,
                     'syndicated': True,
                     "syndication_date": '2000-01-01 00:00:00+00:00',
+                    'nav': [],
                     'site_name': 'Test1 title',
-                    'site_path': '/',
                     'site_url': 'https://www.example.org',
-                    "build_path": "index.html",
                     'template': 'compiled:index.html',
+                    'template_copyright': 'compiled:None',
                     'title': 'Test1 title',
                     'related': {},
                 },
@@ -267,8 +218,10 @@ date: 2010-01-01 00:00:00
             self.assertEqual(mdpage.to_dict(), {
                 "src": {
                     "relpath": "page.md",
-                    "abspath": os.path.join(root, "page.md"),
+                    "abspath": os.path.join(mocksite.root, "page.md"),
                 },
+                'site_path': 'page',
+                "build_path": "page/index.html",
                 "meta": {
                     "author": "Test User",
                     "copyright": '© 2005 Test User',
@@ -278,12 +231,12 @@ date: 2010-01-01 00:00:00
                     'syndicated': True,
                     "syndication_date": '2005-01-01 00:00:00+00:00',
                     'site_name': 'Test1 title',
-                    'site_path': '/page',
                     'site_url': 'https://www.example.org',
-                    "build_path": "page/index.html",
                     'template': 'page.html',
+                    'template_copyright': 'compiled:None',
                     'title': 'Test1 title',
                     'related': {},
+                    'nav': [],
                 },
                 "type": "markdown",
             })
@@ -291,8 +244,10 @@ date: 2010-01-01 00:00:00
             self.assertEqual(datapage.to_dict(), {
                 "src": {
                     "relpath": "page1.yaml",
-                    "abspath": os.path.join(root, "page1.yaml"),
+                    "abspath": os.path.join(mocksite.root, "page1.yaml"),
                 },
+                'site_path': 'page1',
+                "build_path": "page1/index.html",
                 "meta": {
                     "author": "Test User",
                     "copyright": '© 2010 Test User',
@@ -302,13 +257,13 @@ date: 2010-01-01 00:00:00
                     'syndicated': True,
                     "syndication_date": '2010-01-01 00:00:00+00:00',
                     'site_name': 'Test1 title',
-                    'site_path': '/page1',
                     'site_url': 'https://www.example.org',
-                    "build_path": "page1/index.html",
                     'template': 'compiled:data.html',
+                    'template_copyright': 'compiled:None',
                     'title': 'Test1 title',
                     'data_type': 'test',
                     'related': {},
+                    'nav': [],
                 },
                 "type": "data",
             })
